@@ -191,10 +191,10 @@ function allPlaced() {
                 items.categoryReview.score.currentSubLevel ++
         }
     }
-    if(items.categoryReview.score.currentSubLevel == totalImages)
+    if(items.categoryReview.score.currentSubLevel === totalImages)
         items.bonus.good("flower")
     else
-        items.bonus.bad("flower")
+        items.bonus.bad("flower", items.bonus.checkAnswer)
 }
 
 // Save properties to lessons
@@ -298,8 +298,8 @@ function isDragInRightArea(rightAreaLeftBorderPos, elementLeftPos) {
 }
 
 function dropControl(sourcePosition, destinationPosition, image, index) {
-    var destinationZone = destinationPosition == "left" ? items.categoryReview.leftZone : destinationPosition == "right" ? items.categoryReview.rightZone : items.categoryReview.middleZone
-    var sourceZone = sourcePosition == "left" ? items.categoryReview.leftZone : sourcePosition == "right" ? items.categoryReview.rightZone : items.categoryReview.middleZone
+    var destinationZone = destinationPosition === "left" ? items.categoryReview.leftZone : destinationPosition === "right" ? items.categoryReview.rightZone : items.categoryReview.middleZone
+    var sourceZone = sourcePosition === "left" ? items.categoryReview.leftZone : sourcePosition === "right" ? items.categoryReview.rightZone : items.categoryReview.middleZone
     destinationZone.append({"name": image, "droppedZone": destinationPosition})
     sourceZone.remove(index)
 }
