@@ -161,11 +161,11 @@ function checkAnswer() {
             items.bonus.good("flower");
         }
         else {
-            items.bonus.bad("flower");
+            items.bonus.bad("flower", items.bonus.checkAnswer);
         }
     }
     else {
-        items.bonus.bad("flower");
+        items.bonus.bad("flower", items.bonus.checkAnswer);
     }
 }
 
