@@ -49,7 +49,7 @@ public:
     QVariantList allCharacters();
 
 protected Q_SLOTS:
-    Q_INVOKABLE void filterByTag(const QString &tag, bool emitChanged = true);
+    Q_INVOKABLE void filterByTag(const QString &tag, const QString &category = "", bool emitChanged = true);
     Q_INVOKABLE void filterLockedActivities(bool emitChanged = true);
     Q_INVOKABLE void filterEnabledActivities(bool emitChanged = true);
     // create a tree from the whole list of activities with the activities created between the two versions
