@@ -182,6 +182,13 @@ QStringList ApplicationInfo::getFontsFromRcc()
     return m_fontsFromRcc;
 }
 
+QStringList ApplicationInfo::getBackgroundMusicFromRcc()
+{
+    const QStringList backgroundMusicFilters = { QString("*.%1").arg(COMPRESSED_AUDIO) };
+    m_backgroundMusicFromRcc = QDir(":/gcompris/data/backgroundMusic").entryList(backgroundMusicFilters);
+    return m_backgroundMusicFromRcc;
+}
+
 void ApplicationInfo::notifyPortraitMode()
 {
     int width = qApp->primaryScreen()->geometry().width();
@@ -252,7 +259,9 @@ QString ApplicationInfo::getVoicesLocale(const QString &locale)
             _locale = "en_US";
     }
     // locales we have country-specific voices for:
-    if (_locale.startsWith(QLatin1String("pt_BR")) ||
+    if (_locale.startsWith(QLatin1String("en_GB")) ||
+        _locale.startsWith(QLatin1String("en_US")) ||
+        _locale.startsWith(QLatin1String("pt_BR")) ||
         _locale.startsWith(QLatin1String("zh_CN")) ||
         _locale.startsWith(QLatin1String("zh_TW")))
         return QLocale(_locale).name();
