@@ -396,7 +396,10 @@ public slots:
      * @returns A list of fonts contained in the fonts resources.
      */
     Q_INVOKABLE QStringList getFontsFromRcc();
-
+    /**
+     * @returns A list of background music contained in the background music resources.
+     */
+    Q_INVOKABLE QStringList getBackgroundMusicFromRcc();
     /**
      * Stores a screenshot in the passed @p file.
      *
@@ -434,6 +437,7 @@ private:
     // Symbols fonts that user can't see
     QStringList m_excludedFonts;
     QStringList m_fontsFromRcc;
+    QStringList m_backgroundMusicFromRcc;
 
     static QQuickWindow *m_window;
 };
