@@ -30,9 +30,7 @@
 #include <QGuiApplication>
 #include <QScreen>
 #include <QLocale>
-#include <QApplication>
 #include <QRect>
-#include <QDesktopWidget>
 
 #include <QtQml>
 
@@ -51,11 +49,15 @@ static const char *PREVIOUS_WIDTH_KEY = "previousWidth";
 static const char *SHOW_LOCKED_ACTIVITIES_KEY = "showLockedActivities";
 static const char *ENABLE_AUDIO_VOICES_KEY = "enableAudioVoices";
 static const char *ENABLE_AUDIO_EFFECTS_KEY = "enableAudioEffects";
+static const char *ENABLE_BACKGROUND_MUSIC_KEY = "enableBackgroundMusic";
 static const char *VIRTUALKEYBOARD_KEY = "virtualKeyboard";
 static const char *LOCALE_KEY = "locale";
 static const char *FONT_KEY = "font";
 static const char *IS_CURRENT_FONT_EMBEDDED = "isCurrentFontEmbedded";
 static const char *ENABLE_AUTOMATIC_DOWNLOADS = "enableAutomaticDownloads";
+static const char *FILTERED_BACKGROUND_MUSIC_KEY = "filteredBackgroundMusic";
+static const char *BACKGROUND_MUSIC_VOLUME_KEY = "backgroundMusicVolume";
+static const char *AUDIO_EFFECTS_VOLUME_KEY = "audioEffectsVolume";
 
 static const char *DOWNLOAD_SERVER_URL_KEY = "downloadServerUrl";
 static const char *CACHE_PATH_KEY = "cachePath";
@@ -91,13 +93,13 @@ ApplicationSettings::ApplicationSettings(const QString &configPath, QObject *par
      m_fontLetterSpacingMin(0.0), m_fontLetterSpacingMax(8.0),
      m_config(configPath, QSettings::IniFormat)
 {
-    const QRect &screenSize = QApplication::desktop()->screenGeometry();
-
+    const QRect &screenSize = QGuiApplication::screens().at(0)->availableGeometry();
     // initialize from settings file or default
 
     // general group
     m_config.beginGroup(GENERAL_GROUP_KEY);
     m_isAudioEffectsEnabled = m_config.value(ENABLE_AUDIO_EFFECTS_KEY, true).toBool();
+    m_isBackgroundMusicEnabled = m_config.value(ENABLE_BACKGROUND_MUSIC_KEY, true).toBool();
     m_isFullscreen = m_config.value(FULLSCREEN_KEY, true).toBool();
     m_previousHeight = m_config.value(PREVIOUS_HEIGHT_KEY, screenSize.height()).toUInt();
     m_previousWidth = m_config.value(PREVIOUS_WIDTH_KEY, screenSize.width()).toUInt();
@@ -111,6 +113,9 @@ ApplicationSettings::ApplicationSettings(const QString &configPath, QObject *par
     m_fontCapitalization = m_config.value(FONT_CAPITALIZATION, GC_DEFAULT_FONT_CAPITALIZATION).toUInt();
     m_fontLetterSpacing = m_config.value(FONT_LETTER_SPACING, GC_DEFAULT_FONT_LETTER_SPACING).toReal();
     m_isEmbeddedFont = m_config.value(IS_CURRENT_FONT_EMBEDDED, true).toBool();
+    m_filteredBackgroundMusic = m_config.value(FILTERED_BACKGROUND_MUSIC_KEY, ApplicationInfo::getInstance()->getBackgroundMusicFromRcc()).toStringList();
+    m_backgroundMusicVolume = m_config.value(BACKGROUND_MUSIC_VOLUME_KEY, 0.2).toReal();
+    m_audioEffectsVolume = m_config.value(AUDIO_EFFECTS_VOLUME_KEY, 0.7).toReal();
 
     // Init the activation mode
     if(QLatin1String(ACTIVATION_MODE) == "no")
@@ -174,6 +179,8 @@ ApplicationSettings::ApplicationSettings(const QString &configPath, QObject *par
     connect(this, &ApplicationSettings::showLockedActivitiesChanged, this, &ApplicationSettings::notifyShowLockedActivitiesChanged);
     connect(this, &ApplicationSettings::audioVoicesEnabledChanged, this, &ApplicationSettings::notifyAudioVoicesEnabledChanged);
     connect(this, &ApplicationSettings::audioEffectsEnabledChanged, this, &ApplicationSettings::notifyAudioEffectsEnabledChanged);
+    connect(this, &ApplicationSettings::backgroundMusicEnabledChanged, this, &ApplicationSettings::notifyBackgroundMusicEnabledChanged);
+    connect(this, &ApplicationSettings::filteredBackgroundMusicChanged, this, &ApplicationSettings::notifyFilteredBackgroundMusicChanged);
     connect(this, &ApplicationSettings::fullscreenChanged, this, &ApplicationSettings::notifyFullscreenChanged);
     connect(this, &ApplicationSettings::previousHeightChanged, this, &ApplicationSettings::notifyPreviousHeightChanged);
     connect(this, &ApplicationSettings::previousWidthChanged, this, &ApplicationSettings::notifyPreviousWidthChanged);
@@ -195,6 +202,8 @@ ApplicationSettings::ApplicationSettings(const QString &configPath, QObject *par
     connect(this, &ApplicationSettings::exeCountChanged, this, &ApplicationSettings::notifyExeCountChanged);
     connect(this, &ApplicationSettings::barHiddenChanged, this, &ApplicationSettings::notifyBarHiddenChanged);
     connect(this, &ApplicationSettings::lastGCVersionRanChanged, this, &ApplicationSettings::notifyLastGCVersionRanChanged);
+    connect(this, &ApplicationSettings::backgroundMusicVolumeChanged, this, &ApplicationSettings::notifyBackgroundMusicVolumeChanged);
+    connect(this, &ApplicationSettings::audioEffectsVolumeChanged, this, &ApplicationSettings::notifyAudioEffectsVolumeChanged);
 }
 
 ApplicationSettings::~ApplicationSettings()
@@ -204,6 +213,10 @@ ApplicationSettings::~ApplicationSettings()
     m_config.beginGroup(GENERAL_GROUP_KEY);
     m_config.setValue(SHOW_LOCKED_ACTIVITIES_KEY, m_showLockedActivities);
     m_config.setValue(ENABLE_AUDIO_VOICES_KEY, m_isAudioVoicesEnabled);
+    m_config.setValue(ENABLE_BACKGROUND_MUSIC_KEY, m_isBackgroundMusicEnabled);
+    m_config.setValue(FILTERED_BACKGROUND_MUSIC_KEY, m_filteredBackgroundMusic);
+    m_config.setValue(BACKGROUND_MUSIC_VOLUME_KEY, m_backgroundMusicVolume);
+    m_config.setValue(AUDIO_EFFECTS_VOLUME_KEY, m_audioEffectsVolume);
     m_config.setValue(LOCALE_KEY, m_locale);
     m_config.setValue(FONT_KEY, m_font);
     m_config.setValue(IS_CURRENT_FONT_EMBEDDED, m_isEmbeddedFont);
@@ -263,6 +276,30 @@ void ApplicationSettings::notifyAudioEffectsEnabledChanged()
 	qDebug() << "notifyAudioEffects: " << m_isAudioEffectsEnabled;
 }
 
+void ApplicationSettings::notifyBackgroundMusicEnabledChanged()
+{
+    updateValueInConfig(GENERAL_GROUP_KEY, ENABLE_BACKGROUND_MUSIC_KEY, m_isBackgroundMusicEnabled);
+    qDebug() << "notifyBackgroundMusic: " << m_isBackgroundMusicEnabled;
+}
+
+void ApplicationSettings::notifyFilteredBackgroundMusicChanged()
+{
+    updateValueInConfig(GENERAL_GROUP_KEY, FILTERED_BACKGROUND_MUSIC_KEY, m_filteredBackgroundMusic);
+    qDebug()<<"filteredBackgroundMusic: " << m_filteredBackgroundMusic;
+}
+
+void ApplicationSettings::notifyBackgroundMusicVolumeChanged()
+{
+    updateValueInConfig(GENERAL_GROUP_KEY, BACKGROUND_MUSIC_VOLUME_KEY, m_backgroundMusicVolume);
+    qDebug()<<"backgroundMusicVolume: " << m_backgroundMusicVolume;
+}
+
+void ApplicationSettings::notifyAudioEffectsVolumeChanged()
+{
+    updateValueInConfig(GENERAL_GROUP_KEY, AUDIO_EFFECTS_VOLUME_KEY, m_audioEffectsVolume);
+    qDebug()<<"audioEffectsVolume: " << m_audioEffectsVolume;
+}
+
 void ApplicationSettings::notifyLocaleChanged()
 {
     updateValueInConfig(GENERAL_GROUP_KEY, LOCALE_KEY, m_locale);
@@ -326,7 +363,6 @@ void ApplicationSettings::setIsAutomaticDownloadsEnabled(const bool newIsAutomat
         emit automaticDownloadsEnabledChanged();
     }
 }
-
 void ApplicationSettings::notifyAutomaticDownloadsEnabledChanged()
 {
     updateValueInConfig(GENERAL_GROUP_KEY, ENABLE_AUTOMATIC_DOWNLOADS, m_isAutomaticDownloadsEnabled);
@@ -447,7 +483,7 @@ QVariantMap ApplicationSettings::loadActivityConfiguration(const QString &activi
     m_config.beginGroup(activity);
     QStringList keys = m_config.childKeys();
     QVariantMap data;
-    foreach(const QString &key, keys) {
+    for(const QString &key : keys) {
         data[key] = m_config.value(key);
     }
     m_config.endGroup();
