@@ -192,7 +192,9 @@ private:
     void unregisterResource_locked(const QString& filename);
     bool isRegistered(const QString& filename) const;
 
+#if 0
     QStringList getLocalResources();
+#endif
 
 private slots:
 
@@ -235,6 +237,8 @@ public:
      */
     Q_INVOKABLE QString getVoicesResourceForLocale(const QString& locale) const;
 
+    // @returns A relative background music resource path.
+    Q_INVOKABLE QString getBackgroundMusicResources() const;
     /**
      * Checks whether the given relative resource @p path exists locally.
      *
@@ -268,7 +272,7 @@ public:
      */
     Q_INVOKABLE bool areVoicesRegistered() const;
 
-    /*
+    /**
      * Registers a rcc resource file given by a relative resource path
      *
      * @param filename  Relative resource path.
@@ -375,6 +379,14 @@ signals:
      * @sa resourceRegistered
      */
     void voicesRegistered();
+
+    /** Emitted when background music has been registered.
+     *
+     * Convenience signal and special case of resourceRegistered.
+     *
+     * @sa resourceRegistered
+     */
+    void backgroundMusicRegistered();
 };
 
 #endif /* DOWNLOADMANAGER_H */
